@@ -40,7 +40,7 @@ GtkWidget *abort_dialog(gchar *label)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_(""));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Abort"));
 	gtk_signal_connect(GTK_OBJECT(dialog),"delete-event",
 											GTK_SIGNAL_FUNC(gtk_true),NULL);
 	/* ܥ */
