@@ -20,11 +20,14 @@
 #define __ARGUMENT_H__
 
 
-#include <argp.h>
 #include "tmaid.h"
 
 
-extern struct argp argp;
+/*	͂
+	argv,
+	boot,TRUE:N̏
+	 RET,t@Cz														*/
+gboolean *arg_analyse(gchar **argv,gboolean boot);
 
 
 #endif
