@@ -66,7 +66,7 @@ static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 		n_pos=GTK_POS_BOTTOM;
 	gtk_widget_destroy(dialog);
 	/*  */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/File"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	for (i=g_list_length(glist)-3;i>history-(history==0)+MENUFILE-2;i--)
 		gtk_container_remove(GTK_CONTAINER(sub_menu),g_list_nth_data(glist,i));
