@@ -39,7 +39,7 @@ void set_history(gchar *file)
 	GList *glist;
 	GtkWidget *sub_menu,*menu_item;
 
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/File"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	count=g_list_length(glist);
 	for (i=0;i<count-MENUFILE-1;i++) {
@@ -393,7 +393,7 @@ TEXTWND *open_edit_file(gchar *file)
 							GTK_FILL,GTK_EXPAND | GTK_SHRINK | GTK_FILL,0,0);
 	gtk_object_set_user_data(GTK_OBJECT(table),ptw);
 	/* ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/Window"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
 	ptw->menu_item=gtk_menu_item_new_with_label(ptw->file);
 	gtk_signal_connect(GTK_OBJECT(ptw->menu_item),"activate",
 						GTK_SIGNAL_FUNC(signal_activate_menu_window),table);
