@@ -301,9 +301,9 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 			ptw->top.y=ptw->cursor.y-sy+1;
 		move_edit_window(ptw,&top);
 		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw),sx,ptw->top.x);
+										0,get_width_max(ptw)+1,sx,ptw->top.x);
 		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max-1,sy,ptw->top.y);
+										0,ptw->max,sy,ptw->top.y);
 		clear_sel(ptw,&ptw->select,&ptw->cursor);
 		draw_caret(ptw,&cursor);
 		gtk_selection_owner_set(ptw->drawing,GDK_SELECTION_PRIMARY,
