@@ -403,9 +403,9 @@ DOING *edit_operation(TEXTWND *ptw,gchar *text,gint length,
 		ptw->top.x=MAX(max-sx+1,0);
 	move_edit_window(ptw,&top);
 	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-												0,max,sx,ptw->top.x);
+													0,max+1,sx,ptw->top.x);
 	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-												0,ptw->max-1,sy,ptw->top.y);
+													0,ptw->max,sy,ptw->top.y);
 	draw_caret(ptw,NULL);
 	return d;
 }
@@ -582,9 +582,9 @@ void change_property(TEXTWND *ptw,FTYPE *ft)
 	if (ptw->top.x>max-sx+1)
 		ptw->top.x=MAX(max-sx+1,0);
 	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-												0,max,sx,ptw->top.x);
+													0,max+1,sx,ptw->top.x);
 	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-												0,ptw->max-1,sy,ptw->top.y);
+													0,ptw->max,sy,ptw->top.y);
 	/*  */
 	gtk_widget_draw(ptw->drawing,NULL);
 	draw_caret(ptw,NULL);
@@ -693,10 +693,10 @@ void margin_operation(TEXTWND *ptw)
 	ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
 	ptw->select.x=-1;
 	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-		0,get_width_max(ptw),
+		0,get_width_max(ptw)+1,
 		MAX(ptw->drawing->allocation.width/ptw->fontwidth,1),ptw->top.x);
 	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-		0,ptw->max-1,
+		0,ptw->max,
 		MAX(ptw->drawing->allocation.height/ptw->fontheight,1),ptw->top.y);
 	set_menu_bar(ptw);
 	gtk_widget_draw(ptw->drawing,NULL);
