@@ -57,9 +57,9 @@ void jump_operation(TEXTWND *ptw,gint line)
 		ptw->top.y=ptw->cursor.y-sy+1;
 	move_edit_window(ptw,&top);
 	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw),sx,ptw->top.x);
+										0,get_width_max(ptw)+1,sx,ptw->top.x);
 	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max-1,sy,ptw->top.y);
+										0,ptw->max,sy,ptw->top.y);
 	if (ptw->select.x>=0) {
 		if (ptw->select.y==ptw->cursor.y
 									&& ptw->select.x==get_align_pos(ptw,
