@@ -21,6 +21,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <stdio.h>
+#include <string.h>
 #include "abort.h"
 #include "charset.h"
 #include "edit.h"
@@ -112,30 +113,28 @@ gboolean print_out(TEXTWND *ptw,PRNCFG *prncfg)
 					if (p==NULL || !p->margin)
 						break;
 				}
-				if (p->text[datapos]=='\t') {
-					/*  */
+				if (p->text[datapos]=='\t')
 					width=(x/ptw->fontwidth/ptw->tab+1)*ptw->tab
 															*ptw->fontwidth-x;
-					if (sx<width+x)
-						break;
+				else if (datapos+charset_length(p->text[datapos])<=p->length)
+					width=ptw->fontwidth*charset_width(ptw->font,
+											p->text+datapos,ptw->fontwidth);
+				else
+					width=ptw->fontwidth;
+				if (x>0 && sx<x+width)
+					break;
+				if (p->text[datapos]=='\t') {
+					/*  */
 					datapos++;
 				} else if (datapos+charset_length(p->text[datapos])
 																<=p->length) {
 					/* Ⱦ/ */
-					width=ptw->fontwidth*charset_width(ptw->font,
-											p->text+datapos,ptw->fontwidth);
-					if (sx<x+width)
-						break;
-					/* ʸ */
 					gdk_draw_text(pixmap,ptw->font,gc,
 										x,y+ptw->fontascent,p->text+datapos,
 											charset_length(p->text[datapos]));
 					datapos+=charset_length(p->text[datapos]);
 				} else {
 					/* Ⱦ */
-					width=ptw->fontwidth;
-					if (sx<x+width)
-						break;
 					gdk_draw_text(pixmap,ptw->font,gc,
 										x,y+ptw->fontascent,p->text+datapos,1);
 					datapos++;
