@@ -30,10 +30,10 @@ typedef struct replace {
 } REPLACE;
 
 
-extern gboolean replace_arrow;				/* /u̐ݒ */
+extern gboolean replace_arrow;				/* ̐ݒ */
 extern gboolean replace_ignorecase;			/* u̐ݒ */
 extern gchar *replace_text[32];				/* u镶 */
-extern gint replace_num;					/* o^Ă錟/u */
+extern gint replace_num;					/* o^Ău */
 
 
 gint replace_dialog(REPLACE *rp);
