@@ -18,6 +18,7 @@
 */
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
+#include "argument.h"
 #include "charset.h"
 #include "edit.h"
 #include "file.h"
@@ -172,7 +173,7 @@ void signal_value_changed_vscroll(GtkAdjustment *adjust,TEXTWND *ptw)
 	move_edit_window(ptw,&top);
 	if (ptw->top.x!=top.x)
 		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-														0,max,sx,ptw->top.x);
+														0,max+1,sx,ptw->top.x);
 	draw_caret(ptw,NULL);
 }
 
@@ -190,9 +191,9 @@ gboolean signal_config(GtkWidget *widget,
 	if (ptw->top.x>max-sx+1)
 		ptw->top.x=MAX(max-sx+1,0);
 	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-												0,max,sx,ptw->top.x);
+													0,max+1,sx,ptw->top.x);
 	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-												0,ptw->max-1,sy,ptw->top.y);
+													0,ptw->max,sy,ptw->top.y);
 #ifdef USE_XIM
 	if (ptw->ic!=NULL
 				&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)!=0) {
@@ -587,10 +588,10 @@ gboolean signal_button_press(GtkWidget *widget,
 				move_edit_window(ptw,&top);
 				if (ptw->top.x!=top.x)
 					set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,
-											ptw,0,max,sx,ptw->top.x);
+												ptw,0,max+1,sx,ptw->top.x);
 				if (ptw->top.y!=top.y)
 					set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,
-											ptw,0,ptw->max-1,sy,ptw->top.y);
+												ptw,0,ptw->max,sy,ptw->top.y);
 				draw_caret(ptw,NULL);
 			}
 		}
@@ -753,10 +754,10 @@ static gboolean signal_motion_notify_draw(TEXTWND *ptw,gint x,gint y,
 		move_edit_window(ptw,&top);
 		if (ptw->top.x!=top.x)
 			set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw),sx,ptw->top.x);
+										0,get_width_max(ptw)+1,sx,ptw->top.x);
 		if (ptw->top.y!=top.y)
 			set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max-1,sy,ptw->top.y);
+										0,ptw->max,sy,ptw->top.y);
 		draw_caret(ptw,&cursor);
 		clear_sel(ptw,&ptw->cursor,&cursor);
 	}
@@ -1027,10 +1028,10 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 			move_edit_window(ptw,&top);
 			if (ptw->top.x!=top.x)
 				set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw),sx,ptw->top.x);
+										0,get_width_max(ptw)+1,sx,ptw->top.x);
 			if (ptw->top.y!=top.y)
 				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max-1,sy,ptw->top.y);
+										0,ptw->max,sy,ptw->top.y);
 			draw_caret(ptw,&cursor);
 			if (select.x>=0 && ptw->select.x<0)
 				clear_sel(ptw,&select,&cursor);
@@ -1170,10 +1171,10 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 			move_edit_window(ptw,&top);
 			if (ptw->top.x!=top.x)
 				set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw),sx,ptw->top.x);
+										0,get_width_max(ptw)+1,sx,ptw->top.x);
 			if (ptw->top.y!=top.y)
 				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max-1,sy,ptw->top.y);
+										0,ptw->max,sy,ptw->top.y);
 			clear_sel(ptw,&select,&ptw->cursor);
 			draw_caret(ptw,NULL);
 		}
@@ -1277,10 +1278,10 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 			move_edit_window(ptw,&top);
 			if (ptw->top.x!=top.x)
 				set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw),sx,ptw->top.x);
+										0,get_width_max(ptw)+1,sx,ptw->top.x);
 			if (ptw->top.y!=top.y)
 				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max-1,sy,ptw->top.y);
+										0,ptw->max,sy,ptw->top.y);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
 						item_factory_popup,"<main>/Undo"),ptw->undo!=NULL);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
@@ -1416,11 +1417,11 @@ void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
 				ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
 				modify_margin(ptw);
 				set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-														0,get_width_max(ptw),
+														0,get_width_max(ptw)+1,
 						MAX(ptw->drawing->allocation.width/ptw->fontwidth,1),
 																ptw->top.x);
 				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-														0,ptw->max-1,
+														0,ptw->max,
 						MAX(ptw->drawing->allocation.height/ptw->fontheight,1),
 																ptw->top.y);
 			}
@@ -1529,6 +1530,7 @@ gboolean signal_selection_clear(GtkWidget *widget,GdkEventSelection *event,
 															gpointer user_data)
 {
 	if (event->selection==atom_clipboard) {
+		/* åץܡ */
 		g_free(clipboard_text);
 		clipboard_text=NULL;
 	}
@@ -1558,15 +1560,22 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 			text=clipboard_text;
 			length=strlen(clipboard_text);
 		}
-	} else if (data->selection==atom_textmaid) {
+	} else if (data->selection==atom_textmaid0) {
 		/* ץ̿ */
 		text="Text maid Selection";
 		length=strlen(text);
+		gtk_selection_convert(window,atom_textmaid1,
+								GDK_SELECTION_TYPE_STRING,GDK_CURRENT_TIME);
+	} else if (data->selection==atom_textmaid1 && arg_text!=NULL) {
+		/* ץ̿ */
+		text=arg_text;
+		arg_text=NULL;
+		length=strlen(text);
 	}
 	if (text!=NULL) {
 		if (info==TARGET_STRING) {
-			gtk_selection_data_set(data,GDK_SELECTION_TYPE_STRING,
-										8*sizeof(gchar),(guchar *)text,length);
+			gtk_selection_data_set(data,GDK_SELECTION_TYPE_STRING,8,
+														(guchar *)text,length);
 		} else if (info==TARGET_TEXT || info==TARGET_COMPOUND_TEXT) {
 			gdk_string_to_compound_text(text,&encoding,&format,
 											&compound_text,&compound_length);
@@ -1574,7 +1583,8 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 												compound_text,compound_length);
 			gdk_free_compound_text(compound_text);
 		}
-		if (data->selection==GDK_SELECTION_PRIMARY)
+		if (data->selection==GDK_SELECTION_PRIMARY
+											|| data->selection==atom_textmaid1)
 			g_free(text);
 	}
 }
@@ -1583,7 +1593,8 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 												guint time,gpointer user_data)
 {
-	gchar *text=NULL,*tmp,**list;
+	gboolean *arg_files;
+	gchar *text=NULL,*tmp,**list,**argv;
 	gint i,count;
 	DOING *d;
 	TEXTWND *ptw;
@@ -1637,9 +1648,23 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 			ptw->edit=TRUE;
 			g_free(text);
 		}
-	} else if (data->selection==atom_textmaid) {
+	} else if (data->selection==atom_textmaid0) {
 		/* ץ̿ */
 		instance=MAX(data->length,0);
+	} else if (data->selection==atom_textmaid1) {
+		/* ץ̿ */
+		/* ޥɥ饤β */
+		argv=g_strsplit(data->data,"\n",G_MAXINT);
+		init_line=0;
+		arg_files=arg_analyse(argv,FALSE);
+		for (i=0;argv[i]!=NULL;i++)
+			if (arg_files[i]) {
+				ptw=open_edit_file(argv[i]);
+				if (init_line!=0)	/* Ԥ˰ư */
+					jump_operation(ptw,init_line);
+			}
+		g_free(arg_files);
+		g_strfreev(argv);
 	}
 }
 
@@ -1649,61 +1674,6 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 * ʥ/٥ȴؿ(ᥤ)                                             *
 *                                                                             *
 ******************************************************************************/
-gboolean signal_client_event(GtkWidget *widget,GdkEventClient *event,
-															gpointer user_data)
-{
-	gint i;
-	COMM *p;
-	TEXTWND *ptw;
-
-	if (event->message_type==atom_textmaid) {
-		for (p=comm;p!=NULL;p=p->next)
-			if (p->pid==event->data.l[4])
-				break;
-		if (p==NULL) {
-			p=g_malloc(sizeof(COMM));
-			p->arg=NULL;
-			p->leng=0;
-			p->init_line=0;
-			p->pid=event->data.l[4];
-			p->prev=NULL;
-			p->next=comm;
-			if (p->next!=NULL) {
-				p->next->prev=p;
-			}
-			comm=p;
-		}
-		switch (event->data_format) {
-			case 8:
-				p->arg=g_realloc(p->arg,p->leng+16);
-				memcpy(p->arg+p->leng,event->data.b,16);
-				p->leng+=16;
-				for (i=0;i<16;i++)
-					if (event->data.b[i]=='\0')
-						break;
-				if (i<16) {
-					ptw=open_edit_file(p->arg);
-					if (p->init_line!=0)	/* Ԥ˰ư */
-						jump_operation(ptw,p->init_line);
-					g_free(p->arg);
-					if (p->prev!=NULL)
-						p->prev->next=p->next;
-					if (p->next!=NULL)
-						p->next->prev=p->prev;
-					if (comm==p)
-						comm=comm->next;
-					g_free(p);
-				}
-				break;
-			case 32:
-				p->init_line=event->data.l[0];
-		}
-		return TRUE;
-	}
-	return FALSE;
-}
-
-
 gboolean signal_delete(GtkWidget *widget,GdkEvent *event,gpointer user_data)
 {
 	gint page;
