@@ -100,7 +100,7 @@ gboolean valchr_dialog(gchar *valchr)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_("ʸ"));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Character by Value"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(valchr_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
@@ -108,8 +108,8 @@ gboolean valchr_dialog(gchar *valchr)
 	accel=gtk_accel_group_new();
 	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("λ"));
-	button1=gtk_button_new_with_label(_(""));
+	button0=gtk_button_new_with_label(_("OK"));
+	button1=gtk_button_new_with_label(_("Cancel"));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 										valchr_dialog_clicked_ok,valchr);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
@@ -131,13 +131,11 @@ gboolean valchr_dialog(gchar *valchr)
 	radio2=gtk_radio_button_new_with_label_from_widget(
 												GTK_RADIO_BUTTON(radio1),NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),
-															_("16ʿ(_H)"));
+															_("_Hexadecimal"));
 	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),
-															_("10ʿ(_T)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_Decimal"));
 	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),
-															_("8ʿ(_Q)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),_("_Octal"));
 	gtk_widget_add_accelerator(radio2,"clicked",accel,key,GDK_MOD1_MASK,0);
 	switch (valchr_base) {
 	case 16:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio0),TRUE);break;
@@ -151,7 +149,7 @@ gboolean valchr_dialog(gchar *valchr)
 	gtk_signal_connect(GTK_OBJECT(radio2),"clicked",
 									valchr_dialog_clicked_radio,(gpointer)8);
 	/* ե졼ȥܥå */
-	frame=gtk_frame_new(_(""));
+	frame=gtk_frame_new(_("Base"));
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,0);
